AlertInfo class

Constructors

AlertInfo({required String description, String? defaultText, VoidCallback? defaultCallback, bool isDestructive = false, String? cancelText = '', VoidCallback? cancelCallback, List<ButtonConfig> itemList = const []})

Properties

cancelCallback VoidCallback?
final
cancelText String?
final
defaultCallback VoidCallback?
final
defaultText String?
final
description String
final
hashCode int
The hash code for this object.
no setterinherited
isDestructive bool
getter/setter pair
itemList List<ButtonConfig>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited