UserManager class

Available extensions

Constructors

UserManager()

Properties

context Context
latefinal
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
service LiveStreamService
latefinal
userState LSUserState
getter/setter pair

Methods

dispose() → void
init(Context context) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onLeaveLive() → void
onRemoteUserEnterRoom(String roomId, TUIUserInfo userInfo) → void

Available on UserManager, provided by the UserManagerCallback extension

onRemoteUserLeaveRoom(String roomId, TUIUserInfo userInfo) → void

Available on UserManager, provided by the UserManagerCallback extension

onSendMessageForUserDisableChanged(String roomId, String userId, bool isDisable) → void

Available on UserManager, provided by the UserManagerCallback extension

onUserInfoChanged(TUIUserInfo userInfo, List<TUIUserInfoModifyFlag> modifyFlags) → void

Available on UserManager, provided by the UserManagerCallback extension

onUserVoiceVolumeChanged(Map<String, int> volumeMap) → void

Available on UserManager, provided by the UserManagerCallback extension

setLiveID(String liveID) → void
setUserEnterRoomNotifyStrategy(UserEnterRoomNotifyStrategy strategy, {int? intervalSecondOnMerge}) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited