TUIConnectionCode enum

Connection Code.

Inheritance
Available extensions
Annotations
  • @JsonEnum.new(alwaysCreate: true)

Values

unknown → const TUIConnectionCode

default.

success → const TUIConnectionCode

Request success.

roomNotExists → const TUIConnectionCode

Request room not exist.

connecting → const TUIConnectionCode

The room you are invited to connect to is already in the invitation list or is already connected.

connectingOtherRoom → const TUIConnectionCode

The room you are invited to connect to is connecting with other rooms.

connectionFull → const TUIConnectionCode

The current number of connections has reached the maximum limit.

retry → const TUIConnectionCode

Please try again.

roomMismatch → const TUIConnectionCode

Room type mismatch, the connection rooms must be the same type.

Properties

description String?

Available on TUIConnectionCode, provided by the TUIConnectionCodeWithLocalization extension

no setter
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
value() int

Available on TUIConnectionCode, provided by the TUIConnectionCodeExt extension

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<TUIConnectionCode>
A constant List of the values in this enum, in order of their declaration.