LiveThemeManager class
LiveKit theme manager. Switches theme when entering LiveKit scene and restores when exiting. Also supports pausing theme in float window mode.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isInLiveKitScene → bool
-
Whether currently in LiveKit theme mode.
no setter
- isPaused → bool
-
Whether the theme is paused (float window mode).
no setter
- referenceCount → int
-
Current reference count (for debugging).
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
enterLiveKitScene(
BuildContext context, {ThemeType targetTheme = ThemeType.dark}) → void -
Called when entering LiveKit scene.
contextis used to get ThemeState.targetThemeis the target theme, defaults to dark. -
exitLiveKitScene(
) → void - Called when exiting LiveKit scene.
-
forceReset(
) → void - Force reset state (for exceptional cases).
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pauseTheme(
) → void - Called when entering float window mode, temporarily restores the previous theme.
-
resumeTheme(
) → void - Called when returning from float window to fullscreen, restores LiveKit theme.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → LiveThemeManager
-
no setter